qtcore_mapping = {
    'QAbstractAnimation': 'PySide6.QtCore', 'QAbstractEventDispatcher': 'PySide6.QtCore',
    'QAbstractItemModel': 'PySide6.QtCore', 'QAbstractListModel': 'PySide6.QtCore',
    'QAbstractNativeEventFilter': 'PySide6.QtCore', 'QAbstractProxyModel': 'PySide6.QtCore',
    'QAbstractTableModel': 'PySide6.QtCore', 'QAnimationGroup': 'PySide6.QtCore',
    'QBasicTimer': 'PySide6.QtCore', 'QBitArray': 'PySide6.QtCore',
    'QBuffer': 'PySide6.QtCore', 'QByteArray': 'PySide6.QtCore',
    'QByteArrayMatcher': 'PySide6.QtCore', 'QCalendar': 'PySide6.QtCore',
    'QChildEvent': 'PySide6.QtCore', 'QCollator': 'PySide6.QtCore',
    'QCollatorSortKey': 'PySide6.QtCore', 'QCommandLineOption': 'PySide6.QtCore',
    'QCommandLineParser': 'PySide6.QtCore', 'QConcatenateTablesProxyModel': 'PySide6.QtCore',
    'QCoreApplication': 'PySide6.QtCore', 'QCryptographicHash': 'PySide6.QtCore',
    'QDate': 'PySide6.QtCore', 'QDateTime': 'PySide6.QtCore',
    'QDeadlineTimer': 'PySide6.QtCore', 'QDir': 'PySide6.QtCore',
    'QDirIterator': 'PySide6.QtCore', 'QDynamicPropertyChangeEvent': 'PySide6.QtCore',
    'QEasingCurve': 'PySide6.QtCore', 'QElapsedTimer': 'PySide6.QtCore',
    'QEvent': 'PySide6.QtCore', 'QEventLoop': 'PySide6.QtCore',
    'QEventLoopLocker': 'PySide6.QtCore', 'QException': 'PySide6.QtCore',
    'QFile': 'PySide6.QtCore', 'QFileInfo': 'PySide6.QtCore',
    'QFileSelector': 'PySide6.QtCore', 'QFileSystemWatcher': 'PySide6.QtCore',
    'QFinalState': 'PySide6.QtCore', 'QFuture': 'PySide6.QtCore',
    'QFutureIterator': 'PySide6.QtCore', 'QFutureSynchronizer': 'PySide6.QtCore',
    'QFutureWatcher': 'PySide6.QtCore', 'QGenericArgument': 'PySide6.QtCore',
    'QGenericReturnArgument': 'PySide6.QtCore', 'QHistoryState': 'PySide6.QtCore',
    'QIODevice': 'PySide6.QtCore', 'QItemSelection': 'PySide6.QtCore',
    'QItemSelectionModel': 'PySide6.QtCore', 'QItemSelectionRange': 'PySide6.QtCore',
    'QJsonArray': 'PySide6.QtCore', 'QJsonDocument': 'PySide6.QtCore',
    'QJsonObject': 'PySide6.QtCore', 'QJsonParseError': 'PySide6.QtCore',
    'QJsonValue': 'PySide6.QtCore', 'QKeyEventTransition': 'PySide6.QtCore',
    'QLine': 'PySide6.QtCore', 'QLineF': 'PySide6.QtCore',
    'QLocale': 'PySide6.QtCore', 'QMargins': 'PySide6.QtCore',
    'QMarginsF': 'PySide6.QtCore', 'QMessageAuthenticationCode': 'PySide6.QtCore',
    'QMessageLogContext': 'PySide6.QtCore', 'QMetaClassInfo': 'PySide6.QtCore',
    'QMetaEnum': 'PySide6.QtCore', 'QMetaMethod': 'PySide6.QtCore',
    'QMetaObject': 'PySide6.QtCore', 'QMetaProperty': 'PySide6.QtCore',
    'QMimeData': 'PySide6.QtCore', 'QMimeDatabase': 'PySide6.QtCore',
    'QMimeType': 'PySide6.QtCore', 'QModelIndex': 'PySide6.QtCore',
    'QMutex': 'PySide6.QtCore', 'QMutexLocker': 'PySide6.QtCore',
    'QObject': 'PySide6.QtCore', 'QOperatingSystemVersion': 'PySide6.QtCore',
    'QParallelAnimationGroup': 'PySide6.QtCore', 'QPauseAnimation': 'PySide6.QtCore',
    'QPersistentModelIndex': 'PySide6.QtCore', 'QPluginLoader': 'PySide6.QtCore',
    'QPoint': 'PySide6.QtCore', 'QPointF': 'PySide6.QtCore',
    'QProcess': 'PySide6.QtCore', 'QProcessEnvironment': 'PySide6.QtCore',
    'QPropertyAnimation': 'PySide6.QtCore', 'QReadLocker': 'PySide6.QtCore',
    'QReadWriteLock': 'PySide6.QtCore', 'QRect': 'PySide6.QtCore',
    'QRectF': 'PySide6.QtCore', 'QRegExp': 'PySide6.QtCore',
    'QRegularExpression': 'PySide6.QtCore', 'QRegularExpressionMatch': 'PySide6.QtCore',
    'QRegularExpressionMatchIterator': 'PySide6.QtCore', 'QResource': 'PySide6.QtCore',
    'QRunnable': 'PySide6.QtCore', 'QSaveFile': 'PySide6.QtCore',
    'QSemaphore': 'PySide6.QtCore', 'QSemaphoreReleaser': 'PySide6.QtCore',
    'QSequentialAnimationGroup': 'PySide6.QtCore', 'QSettings': 'PySide6.QtCore',
    'QSharedMemory': 'PySide6.QtCore', 'QSignalBlocker': 'PySide6.QtCore',
    'QSignalMapper': 'PySide6.QtCore', 'QSize': 'PySide6.QtCore',
    'QSizeF': 'PySide6.QtCore', 'QSocketNotifier': 'PySide6.QtCore',
    'QSortFilterProxyModel': 'PySide6.QtCore', 'QStandardPaths': 'PySide6.QtCore',
    'QState': 'PySide6.QtCore', 'QStateMachine': 'PySide6.QtCore',
    'QStorageInfo': 'PySide6.QtCore', 'QStringListModel': 'PySide6.QtCore',
    'QSysInfo': 'PySide6.QtCore', 'QSystemSemaphore': 'PySide6.QtCore',
    'QTemporaryDir': 'PySide6.QtCore', 'QTemporaryFile': 'PySide6.QtCore',
    'QTextBoundaryFinder': 'PySide6.QtCore', 'QTextStream': 'PySide6.QtCore',
    'QThread': 'PySide6.QtCore', 'QThreadPool': 'PySide6.QtCore',
    'QThreadStorage': 'PySide6.QtCore', 'QTime': 'PySide6.QtCore',
    'QTimeLine': 'PySide6.QtCore', 'QTimer': 'PySide6.QtCore',
    'QTimerEvent': 'PySide6.QtCore', 'QTranslator': 'PySide6.QtCore',
    'QUrl': 'PySide6.QtCore', 'QUrlQuery': 'PySide6.QtCore',
    'QVariantAnimation': 'PySide6.QtCore', 'QVersionNumber': 'PySide6.QtCore',
    'QWaitCondition': 'PySide6.QtCore', 'QWriteLocker': 'PySide6.QtCore',
    'QXmlStreamAttribute': 'PySide6.QtCore', 'QXmlStreamAttributes': 'PySide6.QtCore',
    'QXmlStreamEntityDeclaration': 'PySide6.QtCore', 'QXmlStreamEntityResolver': 'PySide6.QtCore',
    'QXmlStreamNamespaceDeclaration': 'PySide6.QtCore', 'QXmlStreamNotationDeclaration': 'PySide6.QtCore',
    'QXmlStreamReader': 'PySide6.QtCore', 'QXmlStreamWriter': 'PySide6.QtCore'
}
