qtgui_mapping = {
    'QAbstractFileIconProvider': 'PySide6.QtGui', 'QAbstractTextDocumentLayout': 'PySide6.QtGui',
    'QAction': 'PySide6.QtGui', 'QActionEvent': 'PySide6.QtGui',
    'QBackingStore': 'PySide6.QtGui', 'QBitmap': 'PySide6.QtGui',
    'QBrush': 'PySide6.QtGui', 'QClipboard': 'PySide6.QtGui',
    'QCloseEvent': 'PySide6.QtGui', 'QColor': 'PySide6.QtGui',
    'QConicalGradient': 'PySide6.QtGui', 'QContextMenuEvent': 'PySide6.QtGui',
    'QCursor': 'PySide6.QtGui', 'QDesktopServices': 'PySide6.QtGui',
    'QDoubleValidator': 'PySide6.QtGui', 'QDrag': 'PySide6.QtGui',
    'QDragEnterEvent': 'PySide6.QtGui', 'QDragLeaveEvent': 'PySide6.QtGui',
    'QDragMoveEvent': 'PySide6.QtGui', 'QDropEvent': 'PySide6.QtGui',
    'QEnterEvent': 'PySide6.QtGui', 'QExposeEvent': 'PySide6.QtGui',
    'QFileOpenEvent': 'PySide6.QtGui', 'QFocusEvent': 'PySide6.QtGui',
    'QFont': 'PySide6.QtGui', 'QFontDatabase': 'PySide6.QtGui',
    'QFontInfo': 'PySide6.QtGui', 'QFontMetrics': 'PySide6.QtGui',
    'QFontMetricsF': 'PySide6.QtGui', 'QGestureEvent': 'PySide6.QtGui',
    'QGlyphRun': 'PySide6.QtGui', 'QGradient': 'PySide6.QtGui',
    'QGuiApplication': 'PySide6.QtGui', 'QHelpEvent': 'PySide6.QtGui',
    'QHideEvent': 'PySide6.QtGui', 'QHoverEvent': 'PySide6.QtGui',
    'QIcon': 'PySide6.QtGui', 'QIconDragEvent': 'PySide6.QtGui',
    'QIconEngine': 'PySide6.QtGui', 'QImage': 'PySide6.QtGui',
    'QImageIOHandler': 'PySide6.QtGui', 'QImageReader': 'PySide6.QtGui',
    'QImageWriter': 'PySide6.QtGui', 'QInputEvent': 'PySide6.QtGui',
    'QInputMethodEvent': 'PySide6.QtGui', 'QIntValidator': 'PySide6.QtGui',
    'QKeyEvent': 'PySide6.QtGui', 'QKeySequence': 'PySide6.QtGui',
    'QLinearGradient': 'PySide6.QtGui', 'QMatrix4x4': 'PySide6.QtGui',
    'QMouseEvent': 'PySide6.QtGui', 'QMoveEvent': 'PySide6.QtGui',
    'QMovie': 'PySide6.QtGui', 'QNativeGestureEvent': 'PySide6.QtGui',
    'QOffscreenSurface': 'PySide6.QtGui', 'QOpenGLContext': 'PySide6.QtGui',
    'QOpenGLContextGroup': 'PySide6.QtGui', 'QOpenGLExtraFunctions': 'PySide6.QtGui',
    'QOpenGLFunctions': 'PySide6.QtGui', 'QOpenGLTexture': 'PySide6.QtGui',
    'QPageLayout': 'PySide6.QtGui', 'QPageSize': 'PySide6.QtGui',
    'QPagedPaintDevice': 'PySide6.QtGui', 'QPaintDevice': 'PySide6.QtGui',
    'QPaintEngine': 'PySide6.QtGui', 'QPaintEngineState': 'PySide6.QtGui',
    'QPaintEvent': 'PySide6.QtGui', 'QPainter': 'PySide6.QtGui',
    'QPainterPath': 'PySide6.QtGui', 'QPalette': 'PySide6.QtGui',
    'QPdfWriter': 'PySide6.QtGui', 'QPen': 'PySide6.QtGui',
    'QPicture': 'PySide6.QtGui', 'QPixelFormat': 'PySide6.QtGui',
    'QPixmap': 'PySide6.QtGui', 'QPixmapCache': 'PySide6.QtGui',
    'QPolygon': 'PySide6.QtGui', 'QPolygonF': 'PySide6.QtGui',
    'QRadialGradient': 'PySide6.QtGui', 'QRasterWindow': 'PySide6.QtGui',
    'QRawFont': 'PySide6.QtGui', 'QRegExpValidator': 'PySide6.QtGui',
    'QRegion': 'PySide6.QtGui', 'QRegularExpressionValidator': 'PySide6.QtGui',
    'QResizeEvent': 'PySide6.QtGui', 'QScreen': 'PySide6.QtGui',
    'QScrollEvent': 'PySide6.QtGui', 'QScrollPrepareEvent': 'PySide6.QtGui',
    'QSessionManager': 'PySide6.QtGui', 'QShortcut': 'PySide6.QtGui',
    'QShortcutEvent': 'PySide6.QtGui', 'QShowEvent': 'PySide6.QtGui',
    'QStandardItem': 'PySide6.QtGui', 'QStandardItemModel': 'PySide6.QtGui',
    'QStaticText': 'PySide6.QtGui', 'QStatusTipEvent': 'PySide6.QtGui',
    'QStyleHints': 'PySide6.QtGui', 'QSurface': 'PySide6.QtGui',
    'QSurfaceFormat': 'PySide6.QtGui', 'QSyntaxHighlighter': 'PySide6.QtGui',
    'QTabletEvent': 'PySide6.QtGui', 'QTextBlock': 'PySide6.QtGui',
    'QTextBlockFormat': 'PySide6.QtGui', 'QTextBlockGroup': 'PySide6.QtGui',
    'QTextBlockUserData': 'PySide6.QtGui', 'QTextCharFormat': 'PySide6.QtGui',
    'QTextCursor': 'PySide6.QtGui', 'QTextDocument': 'PySide6.QtGui',
    'QTextDocumentFragment': 'PySide6.QtGui', 'QTextDocumentWriter': 'PySide6.QtGui',
    'QTextFormat': 'PySide6.QtGui', 'QTextFragment': 'PySide6.QtGui',
    'QTextFrame': 'PySide6.QtGui', 'QTextFrameFormat': 'PySide6.QtGui',
    'QTextImageFormat': 'PySide6.QtGui', 'QTextLayout': 'PySide6.QtGui',
    'QTextLength': 'PySide6.QtGui', 'QTextLine': 'PySide6.QtGui',
    'QTextList': 'PySide6.QtGui', 'QTextListFormat': 'PySide6.QtGui',
    'QTextObject': 'PySide6.QtGui', 'QTextObjectInterface': 'PySide6.QtGui',
    'QTextOption': 'PySide6.QtGui', 'QTextTable': 'PySide6.QtGui',
    'QTextTableCell': 'PySide6.QtGui', 'QTextTableCellFormat': 'PySide6.QtGui',
    'QTextTableFormat': 'PySide6.QtGui', 'QTouchEvent': 'PySide6.QtGui',
    'QTransform': 'PySide6.QtGui', 'QUndoCommand': 'PySide6.QtGui',
    'QUndoGroup': 'PySide6.QtGui', 'QUndoStack': 'PySide6.QtGui',
    'QValidator': 'PySide6.QtGui', 'QVector2D': 'PySide6.QtGui',
    'QVector3D': 'PySide6.QtGui', 'QVector4D': 'PySide6.QtGui',
    'QWhatsThisClickedEvent': 'PySide6.QtGui', 'QWheelEvent': 'PySide6.QtGui',
    'QWindow': 'PySide6.QtGui', 'QWindowStateChangeEvent': 'PySide6.QtGui'
}
